==> cssadmin_1.0.3.tar.gz: cssadmin/include/mycssadmin.inc.php <==
<?php
// mycssadmin ver 1.0.3
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/dev>                       //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/ 
// ľܸƤӽФ줿exit
//*****************************************************************************/ 
$replace_array = array( '\\' => '/', '\\.\\' => '/', '/./' => '/' );
if ( strtr($_SERVER['SCRIPT_FILENAME'], $replace_array) === strtr(__FILE__, '\\', '/') )  exit;

if( ! defined( 'XOOPS_ROOT_PATH' ) ) {
	//*************************************************************************/ 
	// ⥸塼뤬󥹥ȡ뤵Ƥʤ˥Ǥ顼޻
	//*************************************************************************/ 
	$display_errors = ini_get( 'display_errors' );
	ini_set( 'display_errors', false );

	//*************************************************************************/ 
	// mainfile.phpɤ߹
	//*************************************************************************/ 
	$root_path_dir = dirname( dirname(dirname(dirname(__FILE__))) );
	include_once( $root_path_dir .'/mainfile.php' );

	//*************************************************************************/ 
	// Ǥ顼޻ߤ
	//*************************************************************************/ 
	$display_errors = ini_get( 'display_errors' );
	ini_set( 'display_errors', $display_errors );
}

//*****************************************************************************/
// ⥸塼ROOT_PATHURLꤹ
//*****************************************************************************/
$mod_path = dirname( dirname(__FILE__) );
$replace_array = array( '\\' => '/', '\\.\\' => '/', '/./' => '/' );
$mod_replace_path = strtr( $mod_path, $replace_array );
$xoops_root_path = strtr( XOOPS_ROOT_PATH, $replace_array );
$mod_url = ( str_replace($xoops_root_path, XOOPS_URL, strtr($mod_replace_path, '\\', '/')) );
$mod_name = basename(dirname(dirname(__FILE__)));

//*****************************************************************************/
// եmycssadmin.phpɤ߹
//*****************************************************************************/
if ( empty($xoopsConfig) ) {
	$config_handler =& xoops_gethandler('config');
	$xoopsConfig =& $config_handler->getConfigsByCat(XOOPS_CONF);
}
include_once( $mod_path .'/language/' .$xoopsConfig['language'] .'/mycssadmin.php' );

//*****************************************************************************/
// ̤ΥإåѹХåե󥰽ɤ߹
//*****************************************************************************/
include_once( $mod_path .'/include/mycssadmin_buf.inc.php' );

//*****************************************************************************/
// ⥸塼ǻѤѿ
//*****************************************************************************/
// DB˳ǼCSSե̾κĹ
$css_max_length = 30;

?>

==> cssadmin_1.0.4.tar.gz: cssadmin/include/mycssadmin.inc.php <==
<?php
// mycssadmin ver 1.0.4
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/dev>                       //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/ 
// ľܸƤӽФ줿exit
//*****************************************************************************/ 
$replace_array = array( '\\' => '/', '\\.\\' => '/', '/./' => '/' );
if ( strtr($_SERVER['SCRIPT_FILENAME'], $replace_array) === strtr(__FILE__, '\\', '/') )  exit;

if( ! defined( 'XOOPS_ROOT_PATH' ) ) {
	//*************************************************************************/ 
	// ⥸塼뤬󥹥ȡ뤵Ƥʤ˥Ǥ顼޻
	//*************************************************************************/ 
	$display_errors = ini_get( 'display_errors' );
	ini_set( 'display_errors', false );

	//*************************************************************************/ 
	// mainfile.phpɤ߹
	//*************************************************************************/ 
	$root_path_dir = dirname( dirname(dirname(dirname(__FILE__))) );
	include_once( $root_path_dir .'/mainfile.php' );

	//*************************************************************************/ 
	// Ǥ顼޻ߤ
	//*************************************************************************/ 
	$display_errors = ini_get( 'display_errors' );
	ini_set( 'display_errors', $display_errors );
}

//*****************************************************************************/
// ⥸塼ROOT_PATHURLꤹ
//*****************************************************************************/
$mod_path = dirname( dirname(__FILE__) );
$replace_array = array( '\\' => '/', '\\.\\' => '/', '/./' => '/' );
$mod_replace_path = strtr( $mod_path, $replace_array );
$xoops_root_path = strtr( XOOPS_ROOT_PATH, $replace_array );
$mod_url = ( str_replace($xoops_root_path, XOOPS_URL, strtr($mod_replace_path, '\\', '/')) );
$mod_name = basename(dirname(dirname(__FILE__)));

//*****************************************************************************/
// եmycssadmin.phpɤ߹
//*****************************************************************************/
if ( empty($xoopsConfig) ) {
	$config_handler =& xoops_gethandler('config');
	$xoopsConfig =& $config_handler->getConfigsByCat(XOOPS_CONF);
}
include_once( $mod_path .'/language/' .$xoopsConfig['language'] .'/mycssadmin.php' );

//*****************************************************************************/
// CSSŬ
//*****************************************************************************/
if ( ! function_exists('mycssAdminBuf') ) {
	function mycssAdminBuf( $buf ) {
		$mod_path = dirname( dirname(__FILE__) );
		$mod_url = str_replace( XOOPS_ROOT_PATH, XOOPS_URL, strtr($mod_path, '\\', '/') );
		$myadmin_css = $mod_url .'/css/mycssadmin.css';
		$module_admin_header = '<link rel="stylesheet" type="text/css" media="screen" href="' .$myadmin_css .'" />' ."\n";
		$buf = str_replace( '</head>', $module_admin_header .'</head>', $buf );
		return $buf;
	}
	
	ob_start( 'mycssAdminBuf' );
}

//*****************************************************************************/
// ⥸塼ǻѤѿ
//*****************************************************************************/
// DB˳ǼCSSե̾κĹ
$css_max_length = 30;

?>
